/** 
 * @file defines ModifyIconCommand, which is executed to modify attributes of the icon from the widget toolbar.
 */

import { Command } from 'ckeditor5/src/core';
import { getSelectedAccordionModelElement } from '../bootstrapaccordionutils';
import type { Element } from 'ckeditor5/src/engine';

/**
 * Represents a command which is executed to modify attributes of the accordion
 * from the widget toolbar.
 */
export default class BootstrapAccordionFirstItemOpenCommand extends Command {

  /**
   * The selected accordion widget.
   */
  public accordionWidget?: Element | null;

  /**
   * The value of this command.
   */
  public override value: boolean;

  /**
   * @inheritdoc
   */
  public override refresh() {
    const model = this.editor.model;
    this.accordionWidget = getSelectedAccordionModelElement(model.document.selection);
    // Disables any BootstrapAccordionFirstItemOpenCommand if there is no
    // selected accordion.
    this.isEnabled = !!this.accordionWidget;
    this.value = false;
    if (this.isEnabled) {
      [...(this.accordionWidget!.getChild(0) as Element).getChildren()].forEach(node => {
        if (node.is('element', 'bootstrapAccordionCollapse')) {
          this.value = node.getAttribute('bootstrapAccordionCollapseShow') === 'true';
        }
      });
    }
  }

  /**
   * @inheritdoc
   */
  public override execute(options: { value: boolean } = { value: false }) {
    const value = options.value;
    const model = this.editor.model;
    const accordionWidget = this.accordionWidget;
    model.change(writer => {
      [...(accordionWidget!.getChild(0) as Element).getChildren()].forEach(node => {
        if (node.is('element', 'bootstrapAccordionHeader')) {
          [...node.getChildren()].forEach(node => {
            if (node.is('element', 'bootstrapAccordionButton')) {
              writer.setAttribute('bootstrapAccordionButtonCollapsed', value ? 'false' : 'true', node);
            }
          });
        } else if (node.is('element', 'bootstrapAccordionCollapse')) {
          writer.setAttribute('bootstrapAccordionCollapseShow', value ? 'true' : 'false', node);
        }
      });
    });
  }

}
