import type { Element, PositionOffset } from 'ckeditor5/src/engine';
import { Command } from 'ckeditor5/src/core';
import { createAccordionItem, getSelectedAccordionItemModelElement } from '../bootstrapaccordionutils';

/**
 * Represents a command which is executed when the insert item above or insert
 * item below button is pressed with an accordion item selected.
 */
export default class InsertBootstrapAccordionItemCommand extends Command {

  /**
   * The currently-selected accordion item.
   */
  protected accordionItem?: Element | null;

  /**
   * @inheritdoc
   */
  override refresh() {
    const selection = this.editor.model.document.selection;
    this.accordionItem = getSelectedAccordionItemModelElement(selection);
    this.isEnabled = !!this.accordionItem;
  }

  /**
   * @inheritdoc
   */
  override execute(options: { value: PositionOffset }) {
    const model = this.editor.model;
    model.change(writer => {
      const { accordionItem } = createAccordionItem(writer);
      writer.insert(accordionItem, this.accordionItem!, options.value);
    });
  }

}
