import type { Element } from 'ckeditor5/src/engine';
import { Command } from 'ckeditor5/src/core';
import { getSelectedAccordionItemModelElement } from '../bootstrapaccordionutils';

/**
 * Represents a command which is executed when the delete item button is
 * pressed with an accordion item selected.
 */
export default class RemoveBootstrapAccordionItemCommand extends Command {

  /**
   * The currently-selected accordion item.
   */
  protected accordionItem?: Element | null;

  /**
   * @inheritdoc
   */
  override execute() {
    this.editor.model.change(writer => {
      writer.remove(this.accordionItem!);
    });
  }

  /**
   * @inheritdoc
   */
  override refresh() {
    const selection = this.editor.model.document.selection;
    this.accordionItem = getSelectedAccordionItemModelElement(selection);
    // Disables the remove command if the accordion has only one item.
    this.isEnabled = this.accordionItem ? 1 < Array.from(this.accordionItem!.parent!.getChildren()).length : false;
  }

}
